pub struct FixedBitSet<const N: usize>{ /* private fields */ }Expand description
A compact fixed-size array of bits.
The N is the number of bits reserved for the bitset. You’re encouraged to
use it like FixedBitSet<20> if you need 20 bits.
Note that this is optimized for fast serialization and deserialization for
Minecraft, and may not be as performant as it could be for other purposes.
Consider using FastFixedBitSet if you don’t need the AzBuf
implementation.
Implementations