pub struct BlockHitResult {
pub location: Vec3,
pub miss: bool,
pub direction: Direction,
pub block_pos: BlockPos,
pub inside: bool,
pub world_border: bool,
}Expand description
The result of raycasting on the blocks in the world.
Also see [HitResult].
Fields
location: Vec3The exact position that the raycast ended at.
miss: booldirection: Directionblock_pos: BlockPosThe block position that was hit.
If Self::miss is true, then this will be the position that the
raycast ended at.
inside: boolworld_border: boolImplementations
Sourceimpl BlockHitResult
impl BlockHitResult
Sourcepub fn miss(location: Vec3, direction: Direction) -> Self
pub fn miss(location: Vec3, direction: Direction) -> Self
Create a new BlockHitResult for when nothing was hit.
pub fn with_direction(&self, direction: Direction) -> Self
pub fn with_position(&self, block_pos: BlockPos) -> Self