pub struct ChunkPos {
pub x: i32,
pub z: i32,
}Expand description
Chunk coordinates are used to represent where a chunk is in the world.
You can convert the x and z to block coordinates by multiplying them by 16.
Fields
x: i32z: i32Implementations