pub struct MinecraftEntityId(pub i32);Expand description
An entity ID used by Minecraft.
These IDs are picked by the server. Some server software (like Bungeecord) may pick entity IDs per-player, so you should avoid relying on them for identifying IDs (especially if you’re using a shared world – i.e. a swarm).
You might find Entity more useful, since that’s an ID decided by us that
is likely to be correct across shared worlds. You could also use the
EntityUuid from azalea_entity, that one is unlikely to change even
across server restarts.
This serializes as a i32. Usually it’s a VarInt in the protocol, but not
always. If you do need it to serialize as a VarInt, make sure to use use the
#[var] attribute.
Tuple Fields
0: i32Trait Implementations
Sourceimpl AzBuf for MinecraftEntityId
impl AzBuf for MinecraftEntityId
fn azalea_read(buf: &mut Cursor<&[u8]>) -> Result<Self, BufReadError>
fn azalea_write(&self, buf: &mut impl Write) -> Result<()>
Sourceimpl AzBufVar for MinecraftEntityId
impl AzBufVar for MinecraftEntityId
fn azalea_read_var(buf: &mut Cursor<&[u8]>) -> Result<Self, BufReadError>
fn azalea_write_var(&self, buf: &mut impl Write) -> Result<()>
Sourceimpl Clone for MinecraftEntityId
impl Clone for MinecraftEntityId
Sourcefn clone(&self) -> MinecraftEntityId
fn clone(&self) -> MinecraftEntityId
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MinecraftEntityId
impl Debug for MinecraftEntityId
Sourceimpl Default for MinecraftEntityId
impl Default for MinecraftEntityId
Sourcefn default() -> MinecraftEntityId
fn default() -> MinecraftEntityId
Returns the “default value” for a type. Read more
Sourceimpl Deref for MinecraftEntityId
impl Deref for MinecraftEntityId
Sourceimpl DerefMut for MinecraftEntityId
impl DerefMut for MinecraftEntityId
Sourceimpl Display for MinecraftEntityId
impl Display for MinecraftEntityId
Sourceimpl From<i32> for MinecraftEntityId
impl From<i32> for MinecraftEntityId
Sourceimpl From<u32> for MinecraftEntityId
impl From<u32> for MinecraftEntityId
Sourceimpl Hash for MinecraftEntityId
impl Hash for MinecraftEntityId
Sourceimpl PartialEq for MinecraftEntityId
impl PartialEq for MinecraftEntityId
impl Copy for MinecraftEntityId
impl Eq for MinecraftEntityId
impl IsEnabled for MinecraftEntityId
impl StructuralPartialEq for MinecraftEntityId